@@ -1,9 +1,10 @@
-__version__ = '0.3.0'
+__version__ = '0.7.0'
 
 from .decorators import process, validation
-from .models import EnumerationValueObject, ValueObject
+from .models import BaseModel, EnumerationValueObject, ValueObject
 
 __all__ = (
+    'BaseModel',
     'EnumerationValueObject',
     'ValueObject',
     'process',
